# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.api.external_system_user_api import ExternalSystemUserApi


class TestExternalSystemUserApi(unittest.IsolatedAsyncioTestCase):
    """ExternalSystemUserApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ExternalSystemUserApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_external_system_user_external_system_user_get(self) -> None:
        """Test case for external_system_user_external_system_user_get

        External System User Get
        """
        pass

    async def test_external_system_user_external_system_user_update(self) -> None:
        """Test case for external_system_user_external_system_user_update

        External System User Update
        """
        pass

    async def test_external_system_user_get_user_by_external_system_info(self) -> None:
        """Test case for external_system_user_get_user_by_external_system_info

        Get User By External System Info
        """
        pass

    async def test_external_system_user_handle_message_from_external_system(self) -> None:
        """Test case for external_system_user_handle_message_from_external_system

        Handle Message From External System
        """
        pass


if __name__ == '__main__':
    unittest.main()
