# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.response_wrapper_list_contact import ResponseWrapperListContact

class TestResponseWrapperListContact(unittest.TestCase):
    """ResponseWrapperListContact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListContact:
        """Test ResponseWrapperListContact
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListContact`
        """
        model = ResponseWrapperListContact()
        if include_optional:
            return ResponseWrapperListContact(
                done = True,
                result = [
                    chat_server_connector_v2.models.contact.Contact(
                        id = 56, 
                        role = 1, 
                        nickname = '', 
                        personal_description = '', 
                        first_name = '', 
                        last_name = '', 
                        avatar_id = '', 
                        is_online = True, 
                        address = null, 
                        phone_number = '', 
                        is_public_email = True, 
                        is_public_phone_number = True, 
                        is_public_city = True, 
                        is_public_country = True, 
                        email = '', )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListContact(
                done = True,
        )
        """

    def testResponseWrapperListContact(self):
        """Test ResponseWrapperListContact"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
